ConnectivityInfo class

Snapshot of the current network route.

Constructors

ConnectivityInfo({required bool isConnected, required String networkType, required bool isMetered, required bool isVpn, required int? signalStrength, required String? ipAddress})
API Documentation for ConnectivityInfo.
const
ConnectivityInfo.fromMap(Map map)
API Documentation for ConnectivityInfo.fromMap.
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
ipAddress String?
API Documentation for ipAddress;.
final
isConnected bool
API Documentation for isConnected;.
final
isMetered bool
API Documentation for isMetered;.
final
isVpn bool
API Documentation for isVpn;.
final
networkType String
API Documentation for networkType;.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signalStrength int?
API Documentation for signalStrength;.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
API Documentation for toMap.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override