models/hardware_capabilities library

Classes

HardwareCapabilities
Describes which SDK features are expected to be available on this runtime.
HardwareFeatureSupport
Detailed feature support metadata for the current runtime.
HardwareShutdownResult
Result returned by NexoraSdk.stopAll.
HardwareStartupResult
Result returned by configured startup helpers.

Enums

HardwareFeature
Hardware features exposed by Nexora SDK.
HardwareFeatureSupportLevel
Coarse-grained implementation status for one feature on one platform.