HardwareFeature enum

Hardware features exposed by Nexora SDK.

Inheritance
Available extensions

Values

camera → const HardwareFeature

API Documentation for camera,.

audio → const HardwareFeature

API Documentation for audio,.

bluetooth → const HardwareFeature

API Documentation for bluetooth,.

location → const HardwareFeature

API Documentation for location,.

biometrics → const HardwareFeature

API Documentation for biometrics,.

sensors → const HardwareFeature

API Documentation for sensors,.

haptics → const HardwareFeature

API Documentation for haptics,.

storage → const HardwareFeature

API Documentation for storage,.

health → const HardwareFeature

API Documentation for health,.

nativeUtilities → const HardwareFeature

API Documentation for nativeUtilities,.

smartSync → const HardwareFeature

API Documentation for smartSync,.

cameraFilters → const HardwareFeature

API Documentation for cameraFilters,.

videoRecording → const HardwareFeature

API Documentation for videoRecording,.

bleL2cap → const HardwareFeature

API Documentation for bleL2cap,.

deadReckoning → const HardwareFeature

API Documentation for deadReckoning,.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<HardwareFeature>
A constant List of the values in this enum, in order of their declaration.