HardwareFeatureSupport class

Detailed feature support metadata for the current runtime.

Constructors

HardwareFeatureSupport({required HardwareFeature feature, required HardwareFeatureSupportLevel level, required String reason, String? requiresMinSdkVersion})
API Documentation for HardwareFeatureSupport.
const

Properties

feature HardwareFeature
API Documentation for feature;.
final
hashCode int
The hash code for this object.
no setterinherited
isAvailable bool
API Documentation for =>.
no setter
isNative bool
API Documentation for HardwareFeatureSupportLevel.supported;.
no setter
level HardwareFeatureSupportLevel
API Documentation for level;.
final
reason String
API Documentation for reason;.
final
requiresMinSdkVersion String?
API Documentation for requiresMinSdkVersion;.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
API Documentation for toMap.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited