HardwareStartupResult class

Result returned by configured startup helpers.

Constructors

HardwareStartupResult(Map<String, bool> results)
Creates a startup result for one or more module start attempts.
const

Properties

failedModules List<String>
Modules that failed to start.
no setter
hashCode int
The hash code for this object.
no setterinherited
results Map<String, bool>
Start result by module name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
Whether every requested module started successfully.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited