HardwareErrorCode enum

Stable SDK error codes for hardware operations.

Inheritance
Available extensions

Values

permissionDenied → const HardwareErrorCode

API Documentation for permissionDenied,.

notSupported → const HardwareErrorCode

API Documentation for notSupported,.

deviceBusy → const HardwareErrorCode

API Documentation for deviceBusy,.

timeout → const HardwareErrorCode

API Documentation for timeout,.

bluetoothUnavailable → const HardwareErrorCode

API Documentation for bluetoothUnavailable,.

cameraUnavailable → const HardwareErrorCode

API Documentation for cameraUnavailable,.

invalidArgument → const HardwareErrorCode

API Documentation for invalidArgument,.

noActivity → const HardwareErrorCode

API Documentation for noActivity,.

nativeError → const HardwareErrorCode

API Documentation for nativeError,.

unknown → const HardwareErrorCode

API Documentation for unknown.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromPlatformCode(String? code) HardwareErrorCode
API Documentation for fromPlatformCode.

Constants

values → const List<HardwareErrorCode>
A constant List of the values in this enum, in order of their declaration.