isUnsupported property
bool
get
isUnsupported
Checks if this exception indicates the feature is not supported.
Implementation
bool get isUnsupported => code == HardwareErrorCode.notSupported;
Checks if this exception indicates the feature is not supported.
bool get isUnsupported => code == HardwareErrorCode.notSupported;