HardwareUnsupportedException class

Thrown when a hardware feature is simply not supported on the current device.

Inheritance

Constructors

HardwareUnsupportedException({required String message, Object? details})
Creates a HardwareUnsupportedException.
const

Properties

code HardwareErrorCode
The standardized error code for the failure.
finalinherited
details Object?
Optional platform-specific details regarding the error.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
isPermissionDenied bool
Checks if this exception indicates missing permissions.
no setterinherited
isUnsupported bool
Checks if this exception indicates the feature is not supported.
no setterinherited
message String
A human-readable description of the error.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited