AiInferenceResult class

Data class representing the result of an AI inference.

Constructors

AiInferenceResult({required Map<String, dynamic> outputs, required int executionTimeMs})
Creates an AiInferenceResult.
AiInferenceResult.fromMap(Map<String, dynamic> map)
Creates an AiInferenceResult from a Map.
factory

Properties

executionTimeMs int
The execution time in milliseconds.
final
hashCode int
The hash code for this object.
no setterinherited
outputs Map<String, dynamic>
The raw tensor outputs mapped by their output names.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited