AndroidLocationOptions class

Advanced Android location customization.

Constructors

AndroidLocationOptions({int updateIntervalMs = 1000, int fastestIntervalMs = 500, int? maxWaitTimeMs, String foregroundServiceType = 'location', String notificationChannelId = 'nexora_location', String notificationTitle = 'Location active', String notificationText = 'Nexora SDK is using location.', int? geofenceDwellMs, String geofenceInitialTrigger = 'enter'})
Creates Android location customization options.
const
AndroidLocationOptions.fromMap(Map map)
Creates options from a serialized map.
factory

Properties

fastestIntervalMs int
Desired fastest update interval.
final
foregroundServiceType String
Android foreground service type string.
final
geofenceDwellMs int?
Optional geofence dwell delay.
final
geofenceInitialTrigger String
Initial geofence trigger preference.
final
hashCode int
The hash code for this object.
no setterinherited
maxWaitTimeMs int?
Desired batching wait time.
final
notificationChannelId String
Notification channel id for foreground work.
final
notificationText String
Foreground notification text.
final
notificationTitle String
Foreground notification title.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updateIntervalMs int
Desired update interval.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Converts this object to a platform-channel map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited