AndroidSensorOptions class

Advanced Android sensor customization.

Constructors

AndroidSensorOptions({List<String> sensorTypes = const <String>['accelerometer', 'gyroscope'], int? batchingLatencyUs, bool emitCalibration = false, bool useWakeUpSensors = false})
Creates Android sensor customization options.
const
AndroidSensorOptions.fromMap(Map map)
Creates options from a serialized map.
factory

Properties

batchingLatencyUs int?
Sensor batching latency in microseconds.
final
emitCalibration bool
Whether calibration status should be emitted.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sensorTypes List<String>
Sensor type names to subscribe to.
final
useWakeUpSensors bool
Whether wake-up sensors should be preferred.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Converts this object to a platform-channel map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited