AudioFrame class

API Documentation for Public member.

Constructors

AudioFrame({required List<double> spectrum, required int sampleRate, Uint8List? bytes})
API Documentation for AudioFrame.
AudioFrame.fromMap(Map map)
API Documentation for AudioFrame.fromMap.
factory

Properties

bytes Uint8List?
API Documentation for bytes;.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleRate int
API Documentation for sampleRate;.
final
spectrum List<double>
API Documentation for spectrum;.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
API Documentation for toMap.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited