AudioInputDevice enum

Target input capture hardware microphones.

Inheritance
Available extensions

Values

defaultMic → const AudioInputDevice

API Documentation for defaultMic,.

frontMic → const AudioInputDevice

API Documentation for frontMic,.

backMic → const AudioInputDevice

API Documentation for backMic,.

bottomMic → const AudioInputDevice

API Documentation for bottomMic,.

bluetoothMic → const AudioInputDevice

API Documentation for bluetoothMic,.

wiredHeadsetMic → const AudioInputDevice

API Documentation for wiredHeadsetMic,.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AudioInputDevice>
A constant List of the values in this enum, in order of their declaration.