AudioOptions class

Customizable audio capture configurations.

Constructors

AudioOptions({int sampleRate = 44100, AudioChannelFormat channels = AudioChannelFormat.mono, bool enableEchoCancellation = true, bool enableNoiseSuppression = true})
API Documentation for AudioOptions.
const
AudioOptions.fromMap(Map map)
Creates audio options from a serialized map.
factory

Properties

channels AudioChannelFormat
API Documentation for channels;.
final
enableEchoCancellation bool
API Documentation for enableEchoCancellation;.
final
enableNoiseSuppression bool
API Documentation for enableNoiseSuppression;.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleRate int
API Documentation for sampleRate;.
final

Methods

copyWith({int? sampleRate, AudioChannelFormat? channels, bool? enableEchoCancellation, bool? enableNoiseSuppression}) AudioOptions
API Documentation for copyWith.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
API Documentation for toMap.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited