BatteryInfo class

API Documentation for Public member.

Constructors

BatteryInfo({required double level, required bool isCharging, required String status, required double temperature})
API Documentation for BatteryInfo.
BatteryInfo.fromMap(Map map)
API Documentation for BatteryInfo.fromMap.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isCharging bool
API Documentation for isCharging;.
final
level double
API Documentation for level;.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
API Documentation for status;.
final
temperature double
API Documentation for temperature;.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object>
API Documentation for toMap.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited