BiometricPromptOptions class
Customization options for native Biometric Prompt overlays (Face ID / Touch ID / Fingerprint).
Constructors
Properties
- confirmationRequired → bool
-
API Documentation for confirmationRequired;.
final
- description → String
-
API Documentation for description;.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- negativeButtonText → String
-
API Documentation for negativeButtonText;.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtitle → String
-
API Documentation for subtitle;.
final
- title → String
-
API Documentation for title;.
final
Methods
-
copyWith(
{String? title, String? subtitle, String? description, String? negativeButtonText, bool? confirmationRequired}) → BiometricPromptOptions - API Documentation for copyWith.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - API Documentation for toMap.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited