BleDevice class

API Documentation for Public member.

Constructors

BleDevice({required String id, required String name, required int rssi})
API Documentation for BleDevice.
BleDevice.fromMap(Map map)
API Documentation for BleDevice.fromMap.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
API Documentation for id;.
final
name String
API Documentation for name;.
final
rssi int
API Documentation for rssi;.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object>
API Documentation for toMap.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited