CameraOptions class

Customizable camera rendering configurations.

Constructors

CameraOptions({CameraQuality resolution = CameraQuality.hd, CameraFocusMode focusMode = CameraFocusMode.continuous, CameraExposureMode exposureMode = CameraExposureMode.auto, double exposureCompensation = 0.0, bool mirrorFrontCamera = true})
API Documentation for CameraOptions.
const

Properties

exposureCompensation double
API Documentation for exposureCompensation;.
final
exposureMode CameraExposureMode
API Documentation for exposureMode;.
final
focusMode CameraFocusMode
API Documentation for focusMode;.
final
hashCode int
The hash code for this object.
no setterinherited
mirrorFrontCamera bool
API Documentation for mirrorFrontCamera;.
final
resolution CameraQuality
API Documentation for resolution;.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({CameraQuality? resolution, CameraFocusMode? focusMode, CameraExposureMode? exposureMode, double? exposureCompensation, bool? mirrorFrontCamera}) CameraOptions
API Documentation for copyWith.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
API Documentation for toMap.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited