DepthOptions class
Options for Depth Camera capturing.
Constructors
- DepthOptions({bool enablePointCloud = true, bool enableDepthMap = false})
- Creates DepthOptions.
Properties
- enableDepthMap → bool
-
Whether to return a depth map (distance matrix).
final
- enablePointCloud → bool
-
Whether to return raw point cloud data.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Converts to Map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited