FileInfo class
Metadata for a file in device storage.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDirectory → bool
-
API Documentation for isDirectory;.
final
- lastModified → DateTime
-
API Documentation for lastModified;.
final
- name → String
-
API Documentation for name;.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → int
-
API Documentation for size;.
final
- sizeFormatted → String
-
Human-readable file size.
no setter
Methods
-
copyWith(
{String? name, int? size, bool? isDirectory, DateTime? lastModified}) → FileInfo - API Documentation for copyWith.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object> - API Documentation for toMap.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited