HapticOptions class

Customization options for high-precision haptics.

Constructors

HapticOptions({HapticFeedbackType type = HapticFeedbackType.medium, int intensityPercent = 100, int durationMs = 50})
API Documentation for HapticOptions.
const
HapticOptions.fromMap(Map map)
Creates haptic options from a serialized map.
factory

Properties

durationMs int
API Documentation for durationMs;.
final
hashCode int
The hash code for this object.
no setterinherited
intensityPercent int
API Documentation for 100.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type HapticFeedbackType
API Documentation for type;.
final

Methods

copyWith({HapticFeedbackType? type, int? intensityPercent, int? durationMs}) HapticOptions
API Documentation for copyWith.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
API Documentation for toMap.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited