IosAudioOptions class

Advanced iOS audio customization.

Constructors

IosAudioOptions({IosAudioSessionCategory category = IosAudioSessionCategory.playAndRecord, IosAudioSessionMode mode = IosAudioSessionMode.defaultMode, bool allowBluetooth = true, bool allowAirPlay = true, bool mixWithOthers = false, bool defaultToSpeaker = true, double? preferredSampleRate, double? preferredBufferDuration})
Creates iOS audio customization options.
const
IosAudioOptions.fromMap(Map map)
Creates options from a serialized map.
factory

Properties

allowAirPlay bool
Whether AirPlay routing is allowed.
final
allowBluetooth bool
Whether Bluetooth routing is allowed.
final
category IosAudioSessionCategory
Audio session category.
final
defaultToSpeaker bool
Whether play-and-record should default output to speaker.
final
hashCode int
The hash code for this object.
no setterinherited
mixWithOthers bool
Whether mixing with other app audio is allowed.
final
mode IosAudioSessionMode
Audio session mode.
final
preferredBufferDuration double?
Preferred IO buffer duration.
final
preferredSampleRate double?
Preferred sample rate.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Converts this object to a platform-channel map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited