IosBiometricOptions class

Advanced iOS biometric customization.

Constructors

IosBiometricOptions({String? localizedFallbackTitle, String? localizedCancelTitle, bool allowDevicePasscode = true, bool invalidateKeysOnEnrollment = true})
Creates iOS biometric customization options.
const
IosBiometricOptions.fromMap(Map map)
Creates options from a serialized map.
factory

Properties

allowDevicePasscode bool
Whether device passcode fallback is allowed.
final
hashCode int
The hash code for this object.
no setterinherited
invalidateKeysOnEnrollment bool
Whether generated keys should invalidate when enrollment changes.
final
localizedCancelTitle String?
iOS cancel button title.
final
localizedFallbackTitle String?
iOS fallback button title.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Converts this object to a platform-channel map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited