IosBluetoothOptions class

Advanced iOS BLE customization.

Constructors

IosBluetoothOptions({String? restoreIdentifier, int? scanTimeoutMs, bool allowDuplicates = false, bool autoReconnect = true, Map<String, Object> filters = const <String, Object>{}})
Creates iOS BLE customization options.
const
IosBluetoothOptions.fromMap(Map map)
Creates options from a serialized map.
factory

Properties

allowDuplicates bool
Whether duplicate advertisements should be delivered.
final
autoReconnect bool
Whether connection helpers should reconnect when possible.
final
filters Map<String, Object>
Service and device filters.
final
hashCode int
The hash code for this object.
no setterinherited
restoreIdentifier String?
CoreBluetooth restore identifier.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scanTimeoutMs int?
Optional scan timeout.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Converts this object to a platform-channel map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited