IosCameraOptions class

Advanced iOS camera customization.

Constructors

IosCameraOptions({NativeCameraLens lens = NativeCameraLens.defaultLens, NativeCameraFps fps = NativeCameraFps.platformDefault, IosCameraSessionPreset sessionPreset = IosCameraSessionPreset.high, bool enableVideoStabilization = true, NativeImageFormat imageFormat = NativeImageFormat.heic, NativeVideoCodec videoCodec = NativeVideoCodec.hevc, int? videoBitrate, NativeVisionPerformanceMode visionPerformanceMode = NativeVisionPerformanceMode.balanced, Map<String, Object> manualControls = const <String, Object>{}})
Creates iOS camera customization options.
const
IosCameraOptions.fromMap(Map map)
Creates options from a serialized map.
factory

Properties

enableVideoStabilization bool
Whether stabilization should be requested.
final
fps NativeCameraFps
Preferred frame rate.
final
hashCode int
The hash code for this object.
no setterinherited
imageFormat NativeImageFormat
Preferred image format.
final
lens NativeCameraLens
Preferred lens.
final
manualControls Map<String, Object>
Manual focus, exposure, ISO, shutter, and white-balance values.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionPreset IosCameraSessionPreset
Preferred AVFoundation session preset.
final
videoBitrate int?
Preferred video bitrate.
final
videoCodec NativeVideoCodec
Preferred video codec.
final
visionPerformanceMode NativeVisionPerformanceMode
Vision detector performance preference.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Converts this object to a platform-channel map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited