IosSensorOptions class

Advanced iOS sensor customization.

Constructors

IosSensorOptions({List<String> sensorTypes = const <String>['accelerometer', 'gyroscope'], double? updateIntervalSeconds, bool emitCalibration = false, bool useDeviceMotionFusion = true})
Creates iOS sensor customization options.
const
IosSensorOptions.fromMap(Map map)
Creates options from a serialized map.
factory

Properties

emitCalibration bool
Whether calibration status should be emitted.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sensorTypes List<String>
Sensor type names to subscribe to.
final
updateIntervalSeconds double?
CoreMotion update interval.
final
useDeviceMotionFusion bool
Whether CoreMotion device-motion fusion should be preferred.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Converts this object to a platform-channel map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited