LocationData class

API Documentation for Public member.

Constructors

LocationData({required double latitude, required double longitude, required double altitude, required double accuracy, required double speed})
API Documentation for LocationData.
LocationData.fromMap(Map map)
API Documentation for LocationData.fromMap.
factory

Properties

accuracy double
API Documentation for accuracy;.
final
altitude double
API Documentation for altitude;.
final
hashCode int
The hash code for this object.
no setterinherited
latitude double
API Documentation for latitude;.
final
longitude double
API Documentation for longitude;.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speed double
API Documentation for speed;.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object>
API Documentation for toMap.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited