LogConfig class
API Documentation for Public member.
Constructors
Properties
- fileName → String
-
API Documentation for fileName;.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- includeGPS → bool
-
API Documentation for includeGPS;.
final
- includeSensors → bool
-
API Documentation for includeSensors;.
final
- intervalMs → int
-
API Documentation for intervalMs;.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? fileName, bool? includeSensors, bool? includeGPS, int? intervalMs}) → LogConfig - API Documentation for copyWith.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object> - API Documentation for toMap.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited