SensorOptions class

Customization options for motion sensors (accelerometer/gyroscope).

Constructors

SensorOptions({SensorAccuracy accuracy = SensorAccuracy.normal, bool enableLowPassFilter = false, double lowPassAlpha = 0.15})
API Documentation for SensorOptions.
const
SensorOptions.fromMap(Map map)
Creates sensor options from a serialized map.
factory

Properties

accuracy SensorAccuracy
API Documentation for accuracy;.
final
enableLowPassFilter bool
API Documentation for enableLowPassFilter;.
final
hashCode int
The hash code for this object.
no setterinherited
lowPassAlpha double
API Documentation for lowPassAlpha;.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({SensorAccuracy? accuracy, bool? enableLowPassFilter, double? lowPassAlpha}) SensorOptions
API Documentation for copyWith.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
API Documentation for toMap.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited