VisionResult class

API Documentation for Public member.

Constructors

VisionResult({List<String> barcodes = const [], List<FaceData> faces = const []})
API Documentation for VisionResult.
VisionResult.fromMap(Map map)
API Documentation for VisionResult.fromMap.
factory

Properties

barcodes List<String>
API Documentation for barcodes;.
final
faces List<FaceData>
API Documentation for faces;.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
API Documentation for toMap.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited