HardwarePermission enum

Runtime permissions managed by Nexora SDK.

Inheritance
Available extensions

Values

camera → const HardwarePermission

API Documentation for camera.

const HardwarePermission('camera')
audio → const HardwarePermission

API Documentation for audio.

const HardwarePermission('audio')
location → const HardwarePermission

API Documentation for location.

const HardwarePermission('location')
bluetooth → const HardwarePermission

API Documentation for bluetooth.

const HardwarePermission('bluetooth')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
API Documentation for value;.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<HardwarePermission>
A constant List of the values in this enum, in order of their declaration.