HardwarePermissionSnapshot class

Snapshot of all core runtime permission states.

Constructors

HardwarePermissionSnapshot(Map<HardwarePermission, HardwarePermissionStatus> statuses)
API Documentation for HardwarePermissionSnapshot.
const

Properties

allGranted bool
API Documentation for statuses.values.every.
no setter
hashCode int
The hash code for this object.
no setterinherited
missingPermissions List<HardwarePermission>
API Documentation for statuses.entries.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statuses Map<HardwarePermission, HardwarePermissionStatus>
API Documentation for statuses;.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
statusFor(HardwarePermission permission) HardwarePermissionStatus
API Documentation for statusFor.
toMap() Map<String, Object>
API Documentation for toMap.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited