HardwarePermissionStatus class

Status for a single hardware permission.

Constructors

HardwarePermissionStatus({required HardwarePermission permission, required HardwarePermissionState state, bool canRequest = true})
API Documentation for HardwarePermissionStatus.
const
HardwarePermissionStatus.fromMap(Map map)
API Documentation for HardwarePermissionStatus.fromMap.
factory

Properties

canRequest bool
API Documentation for canRequest;.
final
hashCode int
The hash code for this object.
no setterinherited
isGranted bool
API Documentation for =>.
no setter
needsSettings bool
API Documentation for HardwarePermissionState.permanentlyDenied;.
no setter
permission HardwarePermission
API Documentation for permission;.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state HardwarePermissionState
API Documentation for state;.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object>
API Documentation for toMap.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited