SensorData class
Encapsulates sensor data from native hardware.
Constructors
- SensorData({required double x, required double y, required double z, required DateTime timestamp})
- API Documentation for SensorData.
- SensorData.fromMap(Map map)
-
Factory constructor to create a SensorData from a map.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
API Documentation for timestamp;.
final
- x → double
-
API Documentation for x;.
final
- y → double
-
API Documentation for y;.
final
- z → double
-
API Documentation for z;.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - API Documentation for toMap.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited