HardwareShutdownResult class
Result returned by NexoraSdk.stopAll.
Constructors
-
HardwareShutdownResult(Map<
String, bool> results) -
API Documentation for HardwareShutdownResult.
const
Properties
-
failedModules
→ List<
String> -
API Documentation for results.entries.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
results
→ Map<
String, bool> -
API Documentation for results;.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success → bool
-
API Documentation for results.values.every.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited