AndroidAudioOptions class
Advanced Android audio customization.
Constructors
- AndroidAudioOptions({AndroidAudioSource source = AndroidAudioSource.mic, bool enableAutomaticGainControl = true, bool enableEchoCancellation = true, bool enableNoiseSuppression = true, bool allowBluetoothSco = true, int bitDepth = 16, int? bufferSize})
-
Creates Android audio customization options.
const
- AndroidAudioOptions.fromMap(Map map)
-
Creates options from a serialized map.
factory
Properties
- allowBluetoothSco → bool
-
Whether Bluetooth SCO microphone routing may be used.
final
- bitDepth → int
-
PCM bit depth preference.
final
- bufferSize → int?
-
Native buffer size preference.
final
- enableAutomaticGainControl → bool
-
Whether Android AGC should be requested.
final
- enableEchoCancellation → bool
-
Whether echo cancellation should be requested.
final
- enableNoiseSuppression → bool
-
Whether noise suppression should be requested.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → AndroidAudioSource
-
Android microphone source.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> - Converts this object to a platform-channel map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited