AndroidBluetoothOptions class
Advanced Android BLE customization.
Constructors
-
AndroidBluetoothOptions({int? scanTimeoutMs, AndroidBleConnectionPriority connectionPriority = AndroidBleConnectionPriority.balanced, int? defaultMtu, bool autoReconnect = true, Map<
String, Object> filters = const <String, Object>{}}) -
Creates Android BLE customization options.
const
- AndroidBluetoothOptions.fromMap(Map map)
-
Creates options from a serialized map.
factory
Properties
- autoReconnect → bool
-
Whether connection helpers should reconnect when possible.
final
- connectionPriority → AndroidBleConnectionPriority
-
Preferred GATT connection priority.
final
- defaultMtu → int?
-
Default MTU requested after connection.
final
-
filters
→ Map<
String, Object> -
Manufacturer, service-data, and device-name filters.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scanTimeoutMs → int?
-
Optional scan timeout.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> - Converts this object to a platform-channel map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited