AndroidNativeOptions class
Android-specific native customization.
Constructors
-
AndroidNativeOptions({AndroidCameraOptions camera = const AndroidCameraOptions(), AndroidAudioOptions audio = const AndroidAudioOptions(), AndroidBluetoothOptions bluetooth = const AndroidBluetoothOptions(), AndroidLocationOptions location = const AndroidLocationOptions(), AndroidSensorOptions sensors = const AndroidSensorOptions(), AndroidBiometricOptions biometrics = const AndroidBiometricOptions(), AndroidSystemOptions system = const AndroidSystemOptions(), Map<
String, Object> extras = const <String, Object>{}}) -
Creates Android native customization options.
const
- AndroidNativeOptions.fromMap(Map map)
-
Creates options from a serialized map.
factory
Properties
- audio → AndroidAudioOptions
-
Android audio options.
final
- biometrics → AndroidBiometricOptions
-
Android biometric options.
final
- bluetooth → AndroidBluetoothOptions
-
Android BLE options.
final
- camera → AndroidCameraOptions
-
Android camera options.
final
-
extras
→ Map<
String, Object> -
Escape hatch for app-specific native extensions.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- location → AndroidLocationOptions
-
Android location options.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sensors → AndroidSensorOptions
-
Android sensor options.
final
- system → AndroidSystemOptions
-
Android system options.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> - Converts this object to a platform-channel map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited