AndroidSystemOptions class
Android native UI/system customization.
Constructors
- AndroidSystemOptions({bool keepScreenOn = false, NativeOrientationLock orientationLock = NativeOrientationLock.system, String? pictureInPictureAspectRatio, bool openExactSettingsPages = true})
-
Creates Android system customization options.
const
- AndroidSystemOptions.fromMap(Map map)
-
Creates options from a serialized map.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- keepScreenOn → bool
-
Whether native code should keep the screen awake.
final
- openExactSettingsPages → bool
-
Whether helpers should open exact settings pages where possible.
final
- orientationLock → NativeOrientationLock
-
Preferred native orientation lock.
final
- pictureInPictureAspectRatio → String?
-
Optional PiP aspect ratio, for example
16:9.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> - Converts this object to a platform-channel map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited