BluetoothScanOptions class
Customization options for BLE scanning.
Constructors
-
BluetoothScanOptions({BluetoothScanMode scanMode = BluetoothScanMode.balanced, List<
String> serviceUuids = const [], bool allowDuplicates = false}) -
API Documentation for BluetoothScanOptions.
const
- BluetoothScanOptions.fromMap(Map map)
-
Creates Bluetooth scan options from a serialized map.
factory
Properties
- allowDuplicates → bool
-
API Documentation for allowDuplicates;.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scanMode → BluetoothScanMode
-
API Documentation for scanMode;.
final
-
serviceUuids
→ List<
String> -
API Documentation for serviceUuids;.
final
Methods
-
copyWith(
{BluetoothScanMode? scanMode, List< String> ? serviceUuids, bool? allowDuplicates}) → BluetoothScanOptions - API Documentation for copyWith.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - API Documentation for toMap.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited