CameraFrame class
Represents a high-performance camera frame or a reference to a GPU texture.
Constructors
- CameraFrame({required int width, required int height, Uint8List? bytes, int? textureId, String format = 'rgba', VisionResult? vision})
- API Documentation for CameraFrame.
- CameraFrame.fromMap(Map map)
-
API Documentation for CameraFrame.fromMap.
factory
Properties
- bytes → Uint8List?
-
Raw image byte data. Null if textureId is being used for rendering.
final
- format → String
-
The pixel format of the data.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int
-
Height of the captured image/texture.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textureId → int?
-
The ID of the native texture for zero-copy GPU rendering.
Use this with Flutter's Texture widget for ultra-low memory usage.
final
- vision → VisionResult?
-
Intelligent vision results (Face/Barcode) if AI mode is active.
final
- width → int
-
Width of the captured image/texture.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> - API Documentation for toMap.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited