FaceData class
API Documentation for Public member.
Constructors
Properties
- boundingBoxLeft → double
-
API Documentation for boundingBoxLeft;.
final
- boundingBoxTop → double
-
API Documentation for boundingBoxTop;.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- smileProb → double?
-
API Documentation for smileProb;.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> - API Documentation for toMap.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited