IosLocationOptions class
Advanced iOS location customization.
Constructors
- IosLocationOptions({bool allowsBackgroundLocationUpdates = false, bool showsBackgroundLocationIndicator = false, bool pausesLocationUpdatesAutomatically = true, bool enableSignificantLocationChanges = false, bool enableVisitMonitoring = false, String activityType = 'other', bool geofenceNotifyOnEntry = true, bool geofenceNotifyOnExit = true})
-
Creates iOS location customization options.
const
- IosLocationOptions.fromMap(Map map)
-
Creates options from a serialized map.
factory
Properties
- activityType → String
-
CoreLocation activity type string.
final
- allowsBackgroundLocationUpdates → bool
-
Whether background updates should be allowed.
final
- enableSignificantLocationChanges → bool
-
Whether significant-change monitoring should be used.
final
- enableVisitMonitoring → bool
-
Whether visit monitoring should be used.
final
- geofenceNotifyOnEntry → bool
-
Whether geofences notify on entry.
final
- geofenceNotifyOnExit → bool
-
Whether geofences notify on exit.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- pausesLocationUpdatesAutomatically → bool
-
Whether iOS can pause updates automatically.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showsBackgroundLocationIndicator → bool
-
Whether the iOS background location indicator should be visible.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> - Converts this object to a platform-channel map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited