IosNativeOptions class
iOS-specific native customization.
Constructors
-
IosNativeOptions({IosCameraOptions camera = const IosCameraOptions(), IosAudioOptions audio = const IosAudioOptions(), IosBluetoothOptions bluetooth = const IosBluetoothOptions(), IosLocationOptions location = const IosLocationOptions(), IosSensorOptions sensors = const IosSensorOptions(), IosBiometricOptions biometrics = const IosBiometricOptions(), IosSystemOptions system = const IosSystemOptions(), Map<
String, Object> extras = const <String, Object>{}}) -
Creates iOS native customization options.
const
- IosNativeOptions.fromMap(Map map)
-
Creates options from a serialized map.
factory
Properties
- audio → IosAudioOptions
-
iOS audio options.
final
- biometrics → IosBiometricOptions
-
iOS biometric options.
final
- bluetooth → IosBluetoothOptions
-
iOS BLE options.
final
- camera → IosCameraOptions
-
iOS camera options.
final
-
extras
→ Map<
String, Object> -
Escape hatch for app-specific native extensions.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- location → IosLocationOptions
-
iOS location options.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sensors → IosSensorOptions
-
iOS sensor options.
final
- system → IosSystemOptions
-
iOS system options.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> - Converts this object to a platform-channel map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited