LocationOptions class
Customization options for GPS and Inertial Sensor Fusion positioning.
Constructors
- LocationOptions({LocationAccuracy accuracy = LocationAccuracy.highAccuracy, double distanceFilterMeters = 0.0, bool enableBackgroundUpdates = false, bool showsBackgroundLocationIndicator = false})
-
API Documentation for LocationOptions.
const
- LocationOptions.fromMap(Map map)
-
Creates location options from a serialized map.
factory
Properties
- accuracy → LocationAccuracy
-
API Documentation for accuracy;.
final
- distanceFilterMeters → double
-
API Documentation for distanceFilterMeters;.
final
- enableBackgroundUpdates → bool
-
API Documentation for enableBackgroundUpdates;.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showsBackgroundLocationIndicator → bool
-
API Documentation for showsBackgroundLocationIndicator;.
final
Methods
-
copyWith(
{LocationAccuracy? accuracy, double? distanceFilterMeters, bool? enableBackgroundUpdates, bool? showsBackgroundLocationIndicator}) → LocationOptions - API Documentation for copyWith.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - API Documentation for toMap.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited