UsbDevice class
Data class representing a connected USB device.
Constructors
Properties
- deviceId → String
-
The unique device identifier (e.g. device path or ID).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- manufacturer → String
-
The manufacturer string.
final
- name → String
-
The product name or description.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Converts this UsbDevice to a Map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited