WifiInfo class
API Documentation for Public member.
Constructors
Properties
- bssid → String
-
API Documentation for bssid;.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- ipAddress → String
-
API Documentation for ipAddress;.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signalStrength → int
-
API Documentation for signalStrength;.
final
- ssid → String
-
API Documentation for ssid;.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object> - API Documentation for toMap.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited