HardwarePermissionReport class
Detailed result for requesting the core runtime permissions.
Constructors
- HardwarePermissionReport({required bool camera, required bool audio, required bool location, required bool bluetooth})
-
API Documentation for HardwarePermissionReport.
const
Properties
- allGranted → bool
-
API Documentation for bluetooth;.
no setter
- audio → bool
-
API Documentation for audio;.
final
- bluetooth → bool
-
API Documentation for bluetooth;.
final
- camera → bool
-
API Documentation for camera;.
final
-
deniedPermissions
→ List<
String> -
API Documentation for
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- location → bool
-
API Documentation for location;.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, bool> - API Documentation for toMap.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited